@@ -6,9 +6,10 @@
 
 #include <QCoreApplication>
 #include <QDBusConnectionInterface>
+#include <QLoggingCategory>
 #include <QObject>
 #include <QSignalSpy>
-#include <QtTest>
+#include <QTest>
 
 #include "../src/backendmanager_p.h"
 #include "../src/config.h"
