@@ -58,6 +58,8 @@ public:
     Q_PROPERTY(bool wcgEnabled READ isWcgEnabled WRITE setWcgEnabled NOTIFY wcgEnabledChanged)
     Q_PROPERTY(AutoRotatePolicy autoRotatePolicy READ autoRotatePolicy WRITE setAutoRotatePolicy NOTIFY autoRotatePolicyChanged)
     Q_PROPERTY(QString iccProfilePath READ iccProfilePath WRITE setIccProfilePath NOTIFY iccProfilePathChanged)
+    Q_PROPERTY(ColorProfileSource colorProfileSource READ colorProfileSource WRITE setColorProfileSource NOTIFY colorProfileSourceChanged)
+    Q_PROPERTY(double brightness READ brightness WRITE setBrightness NOTIFY brightnessChanged)
 
     enum Type {
         Unknown,
@@ -98,6 +100,7 @@ public:
         WideColorGamut = 1 << 4,
         AutoRotation = 1 << 5,
         IccProfile = 1 << 6,
+        BrightnessControl = 1 << 7,
     };
     Q_ENUM(Capability)
     Q_DECLARE_FLAGS(Capabilities, Capability)
@@ -124,6 +127,13 @@ public:
     };
     Q_ENUM(AutoRotatePolicy)
 
+    enum class ColorProfileSource {
+        sRGB = 0,
+        ICC = 1,
+        EDID = 2,
+    };
+    Q_ENUM(ColorProfileSource)
+
     explicit Output();
     ~Output() override;
 
@@ -345,6 +355,17 @@ public:
      */
     QSizeF explicitLogicalSize() const;
 
+    /**
+     * The logical size is the output's representation internal to the display
+     * server and its overall screen geometry.
+     *
+     * returns the logical size of this output, rounded up to the next integer;
+     * is an invalid size if not set
+     *
+     * @since 6.0
+     */
+    QSize explicitLogicalSizeInt() const;
+
     /**
      * Specifies explicitly the logical size of this output and by that overrides any other
      * logical size calculation through mode and scale. To enable this instead again call this
@@ -500,6 +521,12 @@ public:
     std::optional<double> minBrightnessOverride() const;
     void setMinBrightnessOverride(std::optional<double> value);
 
+    ColorProfileSource colorProfileSource() const;
+    void setColorProfileSource(ColorProfileSource source);
+
+    double brightness() const;
+    void setBrightness(double brightness);
+
     void apply(const OutputPtr &other);
 
 Q_SIGNALS:
@@ -532,6 +559,8 @@ Q_SIGNALS:
     void maxPeakBrightnessOverrideChanged();
     void maxAverageBrightnessOverrideChanged();
     void minBrightnessOverrideChanged();
+    void colorProfileSourceChanged();
+    void brightnessChanged();
 
     /** The mode list changed.
      *
